@@ -6,11 +6,12 @@ return [
     'APP_TEST_ACTIVE' => true,
     'PGADMIN_PROD_URL' => 'http://10.100.0.134:5050',
     'PGADMIN_TEST_URL' => 'http://10.100.0.134:5051',
+    'CUSTOM_DOCS_URL' => 'http://10.100.0.134:88',
     'customer' => 'SAF Labs Wtal',
     'mandantory' => 'Vogelsbruch 10, 42111 Wuppertal',
     'licid' => base64_encode('Saf Labs Wtal'),
     'urls' => [
-        ['name' => 'SAFweb2 Docs', 'url' => 'http://10.100.0.134:88', 'desc' => 'Anwenderdokumentation für SAFweb2'],
+        ['name' => 'Anwender Dokumentation', 'url' => 'http://10.100.0.134:88', 'desc' => 'Anwenderdokumentation für SAFweb2'],
         ['name' => 'SAFweb2 Downloads', 'url' => 'http://download.safineia.net/safweb2', 'desc' => 'Alle Anwendungen zum Download'],
     ]
 ];
